menu
semver_sherpa package
documentation
logger.dart
Logger class
Logger class
dark_mode
light_mode
Logger
class
Constructors
Logger
({
bool
debugMode
=
false
})
Properties
debugMode
→
bool
final
hashCode
→
int
The hash code for this object.
no setter
inherited
runtimeType
→
Type
A representation of the runtime type of the object.
no setter
inherited
Methods
debug
(
String
message
)
→ void
error
(
String
message
)
→ void
info
(
String
message
)
→ void
noSuchMethod
(
Invocation
invocation
)
→ dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString
(
)
→
String
A string representation of this object.
inherited
warn
(
String
message
)
→ void
Operators
operator ==
(
Object
other
)
→
bool
The equality operator.
inherited
semver_sherpa package
documentation
logger
Logger class
logger library