SemVer class

Constructors

SemVer(int major, int minor, int patch, {String? preRelease, String? buildMetadata})
SemVer.parse(String input)
factory

Properties

buildMetadata String?
final
buildNumber int
no setter
hashCode int
The hash code for this object.
no setterinherited
major int
final
minor int
final
patch int
final
preRelease String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

bumpMajor() SemVer
bumpMinor() SemVer
bumpPatch() SemVer
bumpPrerelease() SemVer
copyWith({int? major, int? minor, int? patch, String? preRelease, String? buildMetadata}) SemVer
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override
withBuildNumber(int buildNumber) SemVer

Operators

operator ==(Object other) bool
The equality operator.
inherited