RealReleaseExecutor class

Real executor that modifies files and runs git commands

Implemented types

Constructors

RealReleaseExecutor({Logger? logger})

Properties

getLogger → Logger
no setteroverride
hashCode → int
The hash code for this object.
no setterinherited
logger → Logger
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

commit(String message) → Future<void>
override
createTag(String tag) → Future<void>
override
getCommitsSince(String? tag) → Future<List<String>>
override
getCurrentVersion() → String
override
getLastTag() → Future<String?>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
push() → Future<void>
override
toString() → String
A string representation of this object.
inherited
updateVersion(String newVersion) → Future<void>
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited