ReleaseExecutor class abstract

Inheritance
Implemented types
Implementers

Constructors

ReleaseExecutor()

Properties

getLogger → Logger
no setter
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

commit(String message) → Future<void>
createTag(String tag) → Future<void>
getCommitsSince(String? tag) → Future<List<String>>
inherited
getCurrentVersion() → String
inherited
getLastTag() → Future<String?>
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
push() → Future<void>
toString() → String
A string representation of this object.
inherited
updateVersion(String newVersion) → Future<void>

Operators

operator ==(Object other) → bool
The equality operator.
inherited