run method
Fails when the git working tree has uncommitted changes.
Implementation
@override
/// Fails when the git working tree has uncommitted changes.
Future<void> run() async {
final result = await Process.run('git', ['status', '--porcelain']);
if ((result.stdout as String).trim().isNotEmpty) {
throw Exception('The repository has uncommitted changes.');
}
print('Clean repository ✅');
}