VersionService class
Constructors
- VersionService(ReleaseExecutor executor, {DateTimeProvider? now})
Properties
- executor → ReleaseExecutor
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
runRelease(
String bumpType, {bool noCommit = false, bool noTag = false, bool push = false, bool noChangelog = false}) → Future< void> -
setVersion(
String version, {bool noCommit = false, bool noTag = false, bool push = false}) → Future< void> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited